@@ -39,11 +39,13 @@ BED4_CONFIG_FORMAT = """
 [{title}]
 file={file}
 title = {title}
+fontsize = 10
 height = 1
 file_type = bed
 color = {color}
 global_max_row = false
 line_width = 1.5
+labels = {labels}
 """
 
 SPACER = """
@@ -74,6 +76,7 @@ type = vlines
 
 HG19_GENES_PATH = os.path.join(os.path.dirname(__file__), 'hg19.bed12.bed.gz')
 HG38_GENES_PATH = os.path.join(os.path.dirname(__file__), 'hg38.bed12.bed.gz')
+SP9512_GENES_PATH = os.path.join(os.path.dirname(__file__), 'sp9512.bed12.bed.gz')
 GENES_PATH = os.environ.get('GTRACKS_GENES_PATH', HG19_GENES_PATH)
 COLOR_PALETTE = os.environ.get(
     'GTRACKS_COLOR_PALETTE',
@@ -91,10 +94,11 @@ COORD_REGEX = re.compile('(chr)?[0-9XY]+:[0-9]+-[0-9]+$')
 
 GENOME_TO_GENES = {
     'GRCh38': HG38_GENES_PATH, 'hg38': HG38_GENES_PATH,
-    'GRCh37': HG19_GENES_PATH, 'hg19': HG19_GENES_PATH
+    'GRCh37': HG19_GENES_PATH, 'hg19': HG19_GENES_PATH,
+    'Sp9512': SP9512_GENES_PATH
 }
 
-
+SP9512_EXAMPLE_REGION= '7:6975000-6989000'
 
 
 # Functions ====================================================================
@@ -107,7 +111,8 @@ def make_tracks_file(
     color_palette=COLOR_PALETTE,
     genes_height=2,
     gene_rows=1,
-    x_axis='top'
+    x_axis='top',
+    bed_labels=False,
 ):
     X_AXIS_CONFIG = X_AXIS_CONFIG_FORMAT.format(x_axis)
 
@@ -119,7 +124,7 @@ def make_tracks_file(
                 color=color, max=max
             ) if track.endswith('.bw') else SPACER + BED4_CONFIG_FORMAT.format(
                 file=track, title=os.path.basename(track).split('.')[0],
-                color=color
+                color=color, labels=bed_labels
             ) if track.endswith('.bed') else ''
             for track, color in zip(tracks, color_palette[:len(tracks)])
         )
@@ -185,7 +190,7 @@ def parse_arguments():
     )
     parser.add_argument(
         '--genes',
-        metavar='<{path/to/genes.bed.gz,GRCh37,GRCh38,hg19,hg38}>',
+        metavar='<{path/to/genes.bed.gz,GRCh37,GRCh38,hg19,hg38,Sp9512}>',
         default='GRCh37',
         help=(
             'compressed 6-column BED file or 12-column BED12 file containing '
@@ -243,6 +248,11 @@ def parse_arguments():
         metavar='<path/to/vlines.bed>',
         help='BED file defining vertical lines'
     )
+    parser.add_argument(
+        '--bed-labels',
+        action='store_true',
+        help='include labels on BED tracks'
+    )
     args = parser.parse_args()
     for t in args.track:
         if not (t.endswith('.bw') or t.endswith('.bed')):
@@ -276,7 +286,8 @@ def main():
             color_palette=args.color_palette,
             genes_height=args.genes_height,
             gene_rows=args.gene_rows,
-            x_axis=args.x_axis
+            x_axis=args.x_axis,
+            bed_labels=args.bed_labels
         )
         temp_tracks.write(tracks_file.encode())
         temp_tracks.seek(0)
